@@ -19,11 +19,19 @@ use File::Basename;
 my $test_conf = 't/tests-setup.tmp.conf';
 my $test_mark = 't/tests-setup.tmp.OK';
 
+# Temp SQL script files
+my $test_sql_create = './t/create.sql';
+my $test_sql_dropdb = './t/dropdb.sql';
+
 use Test::More;
 
 my $param = read_cached_configs();
 
-unless ( $param->{use_libfbembed} or $ENV{DBI_PASS} or $ENV{ISC_PASSWORD} ) {
+unless ( $param->{use_libfbembed}
+    or $param->{pass}
+    or $ENV{DBI_PASS}
+    or $ENV{ISC_PASSWORD} )
+{
     Test::More->import( skip_all =>
             "Neither DBI_PASS nor ISC_PASSWORD present in the environment" );
     exit 0;    # do not fail with CPAN testers
@@ -110,12 +118,18 @@ Simply (double)check every value and return what's missing.
 sub check_and_set_cached_configs {
     my $param = shift;
 
+    return qq{Please, run "perl Makefile.PL" (to setup isql path)}
+        unless exists $param->{isql};
+
     my $error_str = q{};
 
     # Check user and pass, try the get from ENV if missing
     $param->{user} = $param->{user} ? $param->{user} : get_user($param);
     $param->{pass} = $param->{pass} ? $param->{pass} : get_pass($param);
 
+    # Check host
+    $param->{host} = $param->{host} ? $param->{host} : get_host($param);
+
     # Won't try to find isql here, just repport that it's missing
     $error_str .= ( -x $param->{isql} ) ? q{} : q{isql, };
 
@@ -129,14 +143,11 @@ sub check_and_set_cached_configs {
     $param->{path} = get_path($param);
     my ($base, $path, $type) = fileparse($param->{path}, '\.fdb' );
 
-    # check database path only if local
-    if (   not $path                    # simple file name
-        or $path =~ s/^localhost://i    # leading localhost: stripped
-        or $path =~ /^[a-z]:\\/i        # c:\
-        or $path !~ /^\w\w+:/ )         # /path/to
-    {
+    # Check database path only if local
+    if ( $param->{host} eq 'localhost' ) {
         $error_str .= 'wrong path, '
             if $type eq q{.fdb} and not( -d $path and $base );
+
         # if no .fdb extension, then it may be an alias
     }
 
@@ -161,6 +172,14 @@ sub get_pass {
    return $ENV{DBI_PASS} || $ENV{ISC_PASSWORD} || q{masterkey};
 }
 
+sub get_host {
+   my $param = shift;
+
+   return if $param->{use_libfbembed};
+
+   return q{localhost};
+}
+
 =head2 check_dsn
 
 Parse and check the DSN.
@@ -196,18 +215,21 @@ sub get_dsn {
     my $param = shift;
 
     my $path;
+    my $host = $param->{host};
 
     if ( $param->{use_libfbembed} ) {
         $path = "dbd-fb-testdb.fdb";
     }
     else {
-        $path
-            = 'localhost:'
-            . File::Spec->catfile( File::Spec->tmpdir(),
+        # $path
+        #     = 'localhost:'
+        #     . File::Spec->catfile( File::Spec->tmpdir(),
+        #     'dbd-fb-testdb.fdb' );
+        $path = File::Spec->catfile( File::Spec->tmpdir(),
             'dbd-fb-testdb.fdb' );
     }
 
-    return "dbi:Firebird:db=$path;ib_dialect=3;ib_charset=ISO8859_1";
+    return "dbi:Firebird:db=$path;host=$host;ib_dialect=3;ib_charset=ISO8859_1";
 }
 
 =head2 get_path
@@ -247,7 +269,7 @@ sub setup_test_database {
         create_test_database($param);
 
         # Check again
-        die "Failed to create test database!"
+        return "Failed to create test database!"
           unless $have_testdb = check_database($param);
     }
 
@@ -354,16 +376,18 @@ Create the test database.
 sub create_test_database {
     my $param = shift;
 
-    my ( $isql, $user, $pass, $path ) =
-      ( $param->{isql}, $param->{user}, $param->{pass}, $param->{path} );
+    my ( $isql, $user, $pass, $path, $host ) = (
+        $param->{isql}, $param->{user}, $param->{pass},
+        $param->{path}, $param->{host}
+    );
 
     #- Create test database
 
     #-- Create the SQL file with CREATE statement
 
-    open my $t_fh, '>', './t/create.sql'
-      or die qq{Can't write to t/create.sql};
-    print $t_fh qq{create database "$path"};
+    open my $t_fh, '>', $test_sql_create
+      or die qq{Can't write to $test_sql_create};
+    print $t_fh qq{create database "$host:$path"};
     print $t_fh qq{ user "$user" password "$pass"}
         unless $param->{use_libfbembed};
     print $t_fh ";\nquit;\n";
@@ -372,7 +396,7 @@ sub create_test_database {
     #-- Try to execute isql and create the test database
 
     print 'Create the test database ... ';
-    my $ocmd = qq("$isql" -sql_dialect 3 -i ./t/create.sql 2>&1);
+    my $ocmd = qq("$isql" -sql_dialect 3 -i "$test_sql_create" 2>&1);
     eval {
         # print "cmd is $ocmd\n";
         open( my $isql_fh, '-|', $ocmd ) or die $!;
@@ -407,8 +431,10 @@ If I/O error then conclude that the database doesn't exists.
 sub check_database {
     my $param = shift;
 
-    my ( $isql, $user, $pass, $path ) =
-      ( $param->{isql}, $param->{user}, $param->{pass}, $param->{path} );
+    my ( $isql, $user, $pass, $path, $host ) = (
+        $param->{isql}, $param->{user}, $param->{pass},
+        $param->{path}, $param->{host}
+    );
 
     #- Connect to the test database
 
@@ -421,7 +447,7 @@ sub check_database {
     local $ENV{ISC_USER};
     local $ENV{ISC_PASSWORD};
 
-    my $ocmd = qq("$isql" -x "$path" 2>&1);
+    my $ocmd = qq("$isql" -x "$host:$path" 2>&1);
 
     unless ( $param->{use_libfbembed} ) {
         $ENV{ISC_USER} = $user;
@@ -496,5 +522,93 @@ sub check_mark {
     return (-f $test_mark);
 }
 
-1;
+=head2 drop_test_database
 
+Cleanup time, drop the test database, return 1 on success.
+
+=cut
+
+sub drop_test_database {
+
+    my $param = read_cached_configs();
+
+    return unless scalar %{$param};
+
+    my ( $isql, $user, $pass, $path, $host ) = (
+        $param->{isql}, $param->{user}, $param->{pass},
+        $param->{path}, $param->{host}
+    );
+
+    #-- Create the SQL file with DROP statement
+
+    open my $t_fh, '>', $test_sql_dropdb
+      or die qq{Can't write to $test_sql_dropdb};
+    print $t_fh qq{connect "$host:$path"};
+    print $t_fh qq{ user "$user" password "$pass"}
+        unless $param->{use_libfbembed};
+    print $t_fh qq{;\n};
+    print $t_fh qq{drop database;\n};
+    print $t_fh qq{quit;\n};
+    close $t_fh;
+
+    #-- Try to execute isql
+
+    print 'Drop the test database ... ';
+    my $ocmd = qq("$isql" -sql_dialect 3 -i "$test_sql_dropdb" 2>&1);
+    eval {
+        print "cmd is $ocmd\n";
+        open( my $isql_fh, '-|', $ocmd ) or die $!;
+        while (<$isql_fh>) {
+            # For debug:
+            print "> $_\n";
+        }
+        close $isql_fh;
+    };
+    if ($@) {
+        die "ISQL open error: $@\n";
+    }
+    else {
+        if ( !-f $path ) {
+            print " done\n";
+        }
+        else {
+            print " failed!\n";
+        }
+    }
+
+    return 1;
+}
+
+=head2 cleanup
+
+Cleanup temporary files, return 1 on success.
+
+=cut
+
+sub cleanup {
+
+    my @tmp_files = (
+        $test_conf,
+        $test_mark,
+        $test_sql_create,
+        $test_sql_dropdb,
+    );
+
+    my $unlinked = 0;
+    foreach my $tmp_file (@tmp_files) {
+        print qq{Cleanup $tmp_file };
+        if (unlink $tmp_file) {
+            $unlinked++;
+            print qq{ done\n};
+        }
+        else {
+            print qq{could not unlink: $!\n};
+        }
+    }
+
+    return 1 if $unlinked == scalar @tmp_files;
+
+    return;
+}
+
+1;
